@@ -17,7 +17,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLERR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = POLLERR;
   return 0;
 #else
-  env->die(env, stack, "POLLERR is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLERR is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -29,7 +29,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLHUP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = POLLHUP;
   return 0;
 #else
-  env->die(env, stack, "POLLHUP is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLHUP is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -41,7 +41,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLIN(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = POLLIN;
   return 0;
 #else
-  env->die(env, stack, "POLLIN is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLIN is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -53,7 +53,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLNORM(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = POLLNORM;
   return 0;
 #else
-  env->die(env, stack, "POLLNORM is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLNORM is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -65,7 +65,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLNVAL(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = POLLNVAL;
   return 0;
 #else
-  env->die(env, stack, "POLLNVAL is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLNVAL is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -77,7 +77,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLOUT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = POLLOUT;
   return 0;
 #else
-  env->die(env, stack, "POLLOUT is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLOUT is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -89,7 +89,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLPRI(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = POLLPRI;
   return 0;
 #else
-  env->die(env, stack, "POLLPRI is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLPRI is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -101,7 +101,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLRDBAND(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLLRDBAND;
   return 0;
 #else
-  env->die(env, stack, "POLLRDBAND is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLRDBAND is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -113,7 +113,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLRDNORM(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLLRDNORM;
   return 0;
 #else
-  env->die(env, stack, "POLLRDNORM is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLRDNORM is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -125,7 +125,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLWRBAND(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLLWRBAND;
   return 0;
 #else
-  env->die(env, stack, "POLLWRBAND is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLWRBAND is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
@@ -137,7 +137,7 @@ int32_t SPVM__Sys__Poll__Constant__POLLWRNORM(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLLWRNORM;
   return 0;
 #else
-  env->die(env, stack, "POLLWRNORM is not defined on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "POLLWRNORM is not defined on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
