@@ -10,7 +10,7 @@ static const char* FILE_NAME = "Sys/Time/Tms.c";
 
 int32_t SPVM__Sys__Time__Tms__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The new method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The new method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   
@@ -18,7 +18,7 @@ int32_t SPVM__Sys__Time__Tms__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   struct tms* st_tms = env->new_memory_stack(env, stack, sizeof(struct tms));
 
-  void* obj_st_tms = env->new_pointer_by_name(env, stack, "Sys::Time::Tms", st_tms, &e, FILE_NAME, __LINE__);
+  void* obj_st_tms = env->new_pointer_by_name(env, stack, "Sys::Time::Tms", st_tms, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_st_tms;
@@ -29,7 +29,7 @@ int32_t SPVM__Sys__Time__Tms__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The DESTROY method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The DESTROY method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   
@@ -48,7 +48,7 @@ int32_t SPVM__Sys__Time__Tms__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__tms_utime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The tms_utime method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The tms_utime method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   
@@ -69,7 +69,7 @@ int32_t SPVM__Sys__Time__Tms__tms_utime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__set_tms_utime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The set_tms_utime method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_tms_utime method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   void* obj_self = stack[0].oval;
@@ -90,7 +90,7 @@ int32_t SPVM__Sys__Time__Tms__set_tms_utime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__tms_stime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The tms_stime method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The tms_stime method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   
@@ -111,7 +111,7 @@ int32_t SPVM__Sys__Time__Tms__tms_stime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__set_tms_stime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The set_tms_stime method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_tms_stime method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   void* obj_self = stack[0].oval;
@@ -132,7 +132,7 @@ int32_t SPVM__Sys__Time__Tms__set_tms_stime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__tms_cutime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The tms_cutime method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The tms_cutime method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   
@@ -153,7 +153,7 @@ int32_t SPVM__Sys__Time__Tms__tms_cutime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__set_tms_cutime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The set_tms_cutime method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_tms_cutime method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   void* obj_self = stack[0].oval;
@@ -174,7 +174,7 @@ int32_t SPVM__Sys__Time__Tms__set_tms_cutime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__tms_cstime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The tms_cstime method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The tms_cstime method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   
@@ -195,7 +195,7 @@ int32_t SPVM__Sys__Time__Tms__tms_cstime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__set_tms_cstime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
-  env->die(env, stack, "The set_tms_cstime method in the Sys::Time::Tms is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_tms_cstime method in the Sys::Time::Tms is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   void* obj_self = stack[0].oval;
